@@ -111,37 +111,41 @@ class HLS4MLStrategy(CompilerStrategy):
         firmware_model.compile()
         return firmware_model
 
-
 class ConiferStrategy(CompilerStrategy):
     """Conifer compilation strategy for XGBoost models"""
-    
-    def compile(self, model, workspace: Path, config: Optional[Dict] = None) -> Any:
+
+    def compile(self, model, workspace: Path, config: Optional[Dict] = None, **kwargs) -> Any:
         import conifer
-        
+        import os
+        import shutil
+        import warnings
+
         firmware_dir = workspace / "firmware"
         firmware_dir.mkdir(exist_ok=True)
+
+
+        project_name = kwargs.pop('project_name', None)
         
         cfg = config or conifer.backends.xilinxhls.auto_config()
+        cfg['OutputDir'] = str(firmware_dir)
+        cfg.update(kwargs)
+
         firmware_model = conifer.converters.convert_from_xgboost(
             model,
-            config=cfg,
-            output_dir=str(firmware_dir)
+            config=cfg
         )
+
+        if project_name:
+            firmware_model.config.project_name = project_name
+
         firmware_model.compile()
         if shutil.which("vivado") is not None:
-             firmware_model.build()
+            firmware_model.build()
         else:
             warnings.warn("Vivado not found in PATH. Firmware build failed.", UserWarning)
-        firmware_model.save(workspace / "firmware_model.fml")
-        return firmware_model
-    
-    def load_compiled_model(self, workspace: Path) -> Any:
-        from conifer import load_model
-        
-        firmware_model = load_model(workspace / "firmware_model.fml")
-        firmware_model.compile()
-        return firmware_model
 
+        firmware_model.save(firmware_dir / "firmware_model.fml")
+        return firmware_model
 
 class DA4MLStrategy(CompilerStrategy):
     """DA4ML compilation strategy (placeholder)"""
@@ -202,13 +206,18 @@ class QONNXPredictor(ModelPredictor):
 class FirmwarePredictor(ModelPredictor):
     """Firmware-based model predictor"""
     
-    def __init__(self, firmware_model):
+    def __init__(self, firmware_model, compiler):
         if firmware_model is None:
             raise RuntimeError("Firmware model not built.")
         self.firmware_model = firmware_model
+        self.compiler = compiler
+    
     
     def predict(self, input_data: np.ndarray) -> np.ndarray:
-        return self.firmware_model.predict(input_data)
+        if self.compiler == "conifer":
+            return self.firmware_model.decision_function(input_data)
+        else:
+            return self.firmware_model.predict(input_data)
 
 
 class ConverterFactory:
@@ -363,8 +372,8 @@ class ModelSerializer:
 class TriggerModel:
     """Main facade class that orchestrates model conversion, compilation, and inference"""
     
-    def __init__(self, name: str, ml_backend: str, scales: dict, n_outputs:int, compiler: str,
-                 native_model: object, dataset_object: object, compiler_config: dict = None):
+    def __init__(self, name: str, ml_backend: str, n_outputs:int, compiler: str,
+                 native_model: object, compiler_config: dict = None, scales: dict = None):
         
         if ml_backend.lower() not in ("keras", "xgboost"):
             raise ValueError("Only Keras or XGBoost backends are currently supported.")
@@ -375,7 +384,6 @@ class TriggerModel:
         self.n_outputs = n_outputs
         self.compiler = compiler.lower()
         self.native_model = native_model
-        self.dataset_object = dataset_object
         self.compiler_conifg = compiler_config
         
         self.workspace_manager = WorkspaceManager()
@@ -432,7 +440,8 @@ class TriggerModel:
         
         self.workspace_manager.add_artifact("firmware", self.workspace_manager.workspace / "firmware")
 
-        self.build_emulator(self.scales['shifts'], self.scales['offsets'], self.n_outputs)
+        if self.compiler is not "conifer" and self.scales is not None:
+           self.build_emulator(self.scales['shifts'], self.scales['offsets'], self.n_outputs)
         
         self.workspace_manager.add_artifact("firmware", self.workspace_manager.workspace / "firmware")
         self.workspace_manager.save_metadata()
@@ -466,7 +475,7 @@ class TriggerModel:
     
     def firmware_predict(self, input_data: np.ndarray) -> np.ndarray:
         """Make predictions using firmware model"""
-        predictor = FirmwarePredictor(self.firmware_model)
+        predictor = FirmwarePredictor(self.firmware_model, self.compiler)
         return predictor.predict(input_data)
     
     def build_emulator(self, ad_shift: list, ad_offsets: list, n_outputs: int):
